## [0.12.0](https://github.com/l4rm4nd/PyADRecon/compare/v0.11.14...v0.12.0) (2026-02-21)


### Features

* Implement dashboard generation toggle in arguments ([887ea40](https://github.com/l4rm4nd/PyADRecon/commit/887ea403d7a30a21bbc8feaa67d58eccee88302d))

## [0.11.14](https://github.com/l4rm4nd/PyADRecon/compare/v0.11.13...v0.11.14) (2026-02-20)


### Bug Fixes

* initialize sid mappings earlier to support individual --collect adcs runs ([b036a8f](https://github.com/l4rm4nd/PyADRecon/commit/b036a8fde34eae88cb14e570f9feb92a4a0e0fb3))

## [0.11.13](https://github.com/l4rm4nd/PyADRecon/compare/v0.11.12...v0.11.13) (2026-02-19)


### Bug Fixes

* forest-child enumeration and sid resolving ([10637ff](https://github.com/l4rm4nd/PyADRecon/commit/10637ff68929c00b06df058b3720e26a20975774))

## [0.11.12](https://github.com/l4rm4nd/PyADRecon/compare/v0.11.11...v0.11.12) (2026-02-19)


### Bug Fixes

* add forest_root_dn attribute to track forest root separately ([818acc8](https://github.com/l4rm4nd/PyADRecon/commit/818acc8ce3bb26c1dd05ddd5b763cd8da7282339))

## [0.11.11](https://github.com/l4rm4nd/PyADRecon/compare/v0.11.10...v0.11.11) (2026-02-19)


### Bug Fixes

* ace parsing errors ([20bc72f](https://github.com/l4rm4nd/PyADRecon/commit/20bc72f3ee97b40fa396030b9e49ea2a504740ef))

